@@ -9,38 +9,37 @@
 #' @return A data frame with counted tagged NA values.
 #'
 #' @examples
-#' library(haven)
-#' x <- labelled(
-#'   x = c(1:3, tagged_na("a", "c", "z"),
-#'         4:1, tagged_na("a", "a", "c"),
-#'         1:3, tagged_na("z", "c", "c"),
-#'         1:4, tagged_na("a", "c", "z")),
-#'   labels = c("Agreement" = 1, "Disagreement" = 4,
-#'              "First" = tagged_na("c"), "Refused" = tagged_na("a"),
-#'              "Not home" = tagged_na("z"))
-#' )
-#' count_na(x)
+#' if (require("haven")) {
+#'   x <- labelled(
+#'     x = c(1:3, tagged_na("a", "c", "z"),
+#'           4:1, tagged_na("a", "a", "c"),
+#'           1:3, tagged_na("z", "c", "c"),
+#'           1:4, tagged_na("a", "c", "z")),
+#'     labels = c("Agreement" = 1, "Disagreement" = 4,
+#'                "First" = tagged_na("c"), "Refused" = tagged_na("a"),
+#'                "Not home" = tagged_na("z"))
+#'   )
+#'   count_na(x)
 #'
-#' y <- labelled(
-#'   x = c(1:3, tagged_na("e", "d", "f"),
-#'         4:1, tagged_na("f", "f", "d"),
-#'         1:3, tagged_na("f", "d", "d"),
-#'         1:4, tagged_na("f", "d", "f")),
-#'   labels = c("Agreement" = 1, "Disagreement" = 4, "An E" = tagged_na("e"),
-#'             "A D" = tagged_na("d"), "The eff" = tagged_na("f"))
-#' )
+#'   y <- labelled(
+#'     x = c(1:3, tagged_na("e", "d", "f"),
+#'           4:1, tagged_na("f", "f", "d"),
+#'           1:3, tagged_na("f", "d", "d"),
+#'           1:4, tagged_na("f", "d", "f")),
+#'     labels = c("Agreement" = 1, "Disagreement" = 4, "An E" = tagged_na("e"),
+#'               "A D" = tagged_na("d"), "The eff" = tagged_na("f"))
+#'   )
 #'
-#' # create data frame
-#' dat <- data.frame(x, y)
-#'
-#' # possible count()-function calls
-#' count_na(dat)
-#' count_na(dat$x)
-#' count_na(dat, x)
-#' count_na(dat, x, y)
+#'   # create data frame
+#'   dat <- data.frame(x, y)
 #'
+#'   # possible count()-function calls
+#'   count_na(dat)
+#'   count_na(dat$x)
+#'   count_na(dat, x)
+#'   count_na(dat, x, y)
+#' }
 #' @importFrom dplyr select filter quos
-#' @importFrom haven is_tagged_na na_tag
 #' @importFrom sjlabelled get_label
 #' @export
 count_na <- function(x, ...) {
@@ -82,9 +81,12 @@ count_na <- function(x, ...) {
 
 
 #' @importFrom sjlabelled get_na
-#' @importFrom haven is_tagged_na na_tag
 #' @importFrom dplyr select filter
 count_na_helper <- function(x, cn) {
+  if (!requireNamespace("haven", quietly = TRUE)) {
+    stop("Package `haven` needed for this function to work. Please install it.", call. = FALSE)
+  }
+
   # check if x has any tagged NA values
   if (sum(haven::is_tagged_na(x)) < 1) {
     message("`x` has no tagged NA values.")
